#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 ghcide
version:              2.3.0.0
visibility:           public
id:                   ghcide-2.3.0.0-QtCqgkAhjlupfC2pm4el
key:                  ghcide-2.3.0.0-QtCqgkAhjlupfC2pm4el
license:              Apache-2.0
copyright:            Digital Asset and Ghcide contributors 2018-2020
maintainer:           Ghcide contributors
author:               Digital Asset and Ghcide contributors
homepage:
    https://github.com/haskell/haskell-language-server/tree/master/ghcide#readme

synopsis:             The core of an IDE
description:          A library for building Haskell IDE'\''s on top of the GHC API.
category:             Development
abi:                  9561f15767a544240512d3ec1c717120
exposed:              True
exposed-modules:
    Control.Concurrent.Strict Development.IDE
    Development.IDE.Core.Actions Development.IDE.Core.Compile
    Development.IDE.Core.Debouncer Development.IDE.Core.FileStore
    Development.IDE.Core.FileUtils
    Development.IDE.Core.IdeConfiguration
    Development.IDE.Core.OfInterest Development.IDE.Core.PluginUtils
    Development.IDE.Core.PositionMapping
    Development.IDE.Core.Preprocessor
    Development.IDE.Core.ProgressReporting
    Development.IDE.Core.RuleTypes Development.IDE.Core.Rules
    Development.IDE.Core.Service Development.IDE.Core.Shake
    Development.IDE.Core.Tracing Development.IDE.Core.UseStale
    Development.IDE.GHC.Compat Development.IDE.GHC.Compat.Core
    Development.IDE.GHC.Compat.Env Development.IDE.GHC.Compat.Iface
    Development.IDE.GHC.Compat.Logger
    Development.IDE.GHC.Compat.Outputable
    Development.IDE.GHC.Compat.Parser
    Development.IDE.GHC.Compat.Plugins Development.IDE.GHC.Compat.Units
    Development.IDE.GHC.Compat.Util Development.IDE.GHC.CoreFile
    Development.IDE.GHC.Error Development.IDE.GHC.Orphans
    Development.IDE.GHC.Util
    Development.IDE.Import.DependencyInformation
    Development.IDE.Import.FindImports
    Development.IDE.LSP.HoverDefinition
    Development.IDE.LSP.LanguageServer
    Development.IDE.LSP.Notifications Development.IDE.LSP.Outline
    Development.IDE.LSP.Server Development.IDE.Main
    Development.IDE.Main.HeapStats Development.IDE.Monitoring.EKG
    Development.IDE.Monitoring.OpenTelemetry Development.IDE.Plugin
    Development.IDE.Plugin.Completions
    Development.IDE.Plugin.Completions.Types Development.IDE.Plugin.HLS
    Development.IDE.Plugin.HLS.GhcIde Development.IDE.Plugin.Test
    Development.IDE.Plugin.TypeLenses Development.IDE.Session
    Development.IDE.Session.Diagnostics Development.IDE.Spans.AtPoint
    Development.IDE.Spans.Common Development.IDE.Spans.Documentation
    Development.IDE.Spans.LocalBindings Development.IDE.Spans.Pragmas
    Development.IDE.Types.Diagnostics Development.IDE.Types.Exports
    Development.IDE.Types.HscEnvEq Development.IDE.Types.KnownTargets
    Development.IDE.Types.Location Development.IDE.Types.Monitoring
    Development.IDE.Types.Options Development.IDE.Types.Shake
    Generics.SYB.GHC Text.Fuzzy.Parallel

hidden-modules:
    Development.IDE.Core.FileExists Development.IDE.GHC.CPP
    Development.IDE.GHC.Warnings
    Development.IDE.Plugin.Completions.Logic
    Development.IDE.Session.VersionCheck Development.IDE.Types.Action

import-dirs:          /usr/lib/ghc-9.6.6/site-local/ghcide-2.3.0.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/ghcide-2.3.0.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/ghcide-2.3.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-ghcide
hs-libraries:         HSghcide-2.3.0.0-QtCqgkAhjlupfC2pm4el
depends:
    Diff-0.5-Am7LKUlc3753Bz8cDMWPBf Glob-0.10.2-E9Ofy58UjcEDtLkuI1NiLV
    aeson-2.2.1.0-FEnGzvKMunxDwDFhBeJYHO array-0.5.6.0
    async-2.2.6-9S5YBpAZQ2fGtiHAvRKHi7 base-4.18.2.1
    base16-bytestring-1.0.2.0-BrKum4UJoGp9BOvJ2feb26 binary-0.8.9.1
    bytestring-0.11.5.3 case-insensitive-1.2.1.0-DkQB71KJg2v82iYJB6vXcb
    co-log-core-0.3.2.6-D87yZYcUfEep9NLn4SFvW containers-0.6.7
    cryptohash-sha1-0.11.101.0-Lov2ggmHgUjLR1ewQZW1C1
    data-default-0.7.1.3-EtVHsfbH5oIpJ9umzYHUz deepseq-1.4.8.1
    dependent-map-0.4.0.1-Cy96f04iJum7y0U9VrZrkL
    dependent-sum-0.7.2.0-ICFXSSsaWfT9n6Xe6Lxbga directory-1.3.8.5
    dlist-1.0-B7D1vsARFiIHVaGk5CGbYO
    enummapset-0.7.3.0-LveXZRf2lnZ243PdjvVPey exceptions-0.10.7
    extra-1.7.16-GBHSV2ca01pLlBBatrwGfL filepath-1.4.300.1
    fingertree-0.1.6.3-D9hLAOnWRHQ4hSuewhJE1T
    focus-1.0.3.2-GQmjW6E8cwoJjtDrRnTEdZ ghc-9.6.6 ghc-boot-9.6.6
    ghc-boot-th-9.6.6 ghc-check-0.5.0.8-JfBGVPWgEQ3E60Ue4UlyGG
    ghc-paths-0.1.0.12-JSGGj7CcxjZ2Iy0LlOG5cZ
    ghc-trace-events-0.1.2.10-H26I0MYftT2GE85bySiIsN
    haddock-library-1.11.0-F3OZ1w5XXWf44zKDLFnHVM
    hashable-1.4.7.0-H7NkROSKCrjFQZGpvHIgO1
    hie-bios-0.12.0-YlKiHvZLQWQbDC126Kgv
    hie-compat-0.3.1.2-37lTPgU0jdr1Ufn5QvEKoZ
    hiedb-0.4.3.0-GcFOGOZsKWC6CTkUymmo3A
    hls-graph-2.3.0.0-BAYM23mlPsq36zbYI95vnn
    hls-plugin-api-2.3.0.0-D6yfjm5Qm5fLxsApgswhjH
    implicit-hie-0.1.4.0-nhGVXaI6IdEhNOU8aSZV2
    implicit-hie-cradle-0.5.0.1-JYRCYGuOQXWBGRrYFxqQ53
    lens-5.3.4-B9QPRzrMZ8J355CXfNFvnN
    list-t-1.0.5.7-FErBShpQNGcHx5YOp9YnaE
    lsp-2.2.0.0-81EvswuDs4iK20QcL1dFFp
    lsp-types-2.0.2.0-6fRnHC0piWmLNGya7ZKBXV mtl-2.3.1
    opentelemetry-0.8.0-IkemzZEZOX929EEnd7XDU8
    optparse-applicative-0.18.1.0-JYwGc1030kp1M9C8Y9ZIot
    parallel-3.2.2.0-4GFGhbl8Ae06nPoqdIyBUD
    prettyprinter-1.7.1-SaqeLf0VF75CcRG6tvr9r
    prettyprinter-ansi-terminal-1.1.3-AtzM4takVDM8qT5kzuvjEH
    random-1.2.1.3-EZAJJDcAdrKCzLsP4iSxFh
    regex-tdfa-1.3.2.5-Bvc9BIe1kOc26Ws9LH5CKW
    row-types-1.0.1.2-8UtqxaozlYp4RcQR3tmfvC
    safe-exceptions-0.1.7.4-K4HYEDcFw43KWJNmuhqM8J
    sorted-list-0.2.3.1-23YGAprarO5AJhoczm2jF3
    sqlite-simple-0.4.19.0-FR1ZaIODG6jriDvJY44ge stm-2.5.1.0
    stm-containers-1.2.1.1-Ju1Apz93ZEd1zdpdcfHb21
    syb-0.7.3-H7QXegMKksQGc4JgI4csk0 text-2.0.2
    text-rope-0.3-2uUblqklLbMABDnE4Bf4VV time-1.12.2
    transformers-0.6.1.0 unix-2.8.4.0
    unliftio-0.2.25.1-H2bxXnnkRB0DM3bojqNUxO
    unliftio-core-0.2.1.0-6sOpIonHj8t5wIbPhWbPHY
    unordered-containers-0.2.20.1-2pZfUb3hQF1KSawFItMd4V
    vector-0.13.2.0-BkeaBlIIAt9GprLstCadki

haddock-interfaces:   /usr/share/doc/haskell-ghcide/html/ghcide.haddock
haddock-html:         /usr/share/doc/haskell-ghcide/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

